@@ -1,7 +1,7 @@
 package Org::Document;
 
 our $DATE = '2016-07-14'; # DATE
-our $VERSION = '0.48'; # VERSION
+our $VERSION = '0.49'; # VERSION
 
 use 5.010;
 use locale;
@@ -141,7 +141,7 @@ sub __format_args {
     my ($args) = @_;
     my @s;
     for (@$args) {
-        if (/\A[A-Za-z0-9_:-]+\z/) {
+        if (/\A(?:[A-Za-z0-9_:-]+|\|)\z/) {
             push @s, $_;
         } elsif (/"/) {
             push @s, qq('$_');
@@ -787,7 +787,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.48 of Org::Document (from Perl distribution Org-Parser), released on 2016-07-14.
+This document describes version 0.49 of Org::Document (from Perl distribution Org-Parser), released on 2016-07-14.
 
 =head1 SYNOPSIS
 
