@@ -6,7 +6,7 @@ use Moo;
 use experimental 'smartmatch';
 extends 'Org::Element';
 
-our $VERSION = '0.48'; # VERSION
+our $VERSION = '0.49'; # VERSION
 
 our @known_settings = qw(
 ARCHIVE
@@ -164,7 +164,7 @@ sub as_string {
     my ($self) = @_;
     join("",
          $self->indent // "",
-         "#+".uc($self->name),
+         "#+".uc($self->name), ":",
          $self->args && @{$self->args} ?
              " ".Org::Document::__format_args($self->args) : "",
          "\n"
@@ -186,7 +186,7 @@ Org::Element::Setting - Represent Org in-buffer settings
 
 =head1 VERSION
 
-This document describes version 0.48 of Org::Element::Setting (from Perl distribution Org-Parser), released on 2016-07-14.
+This document describes version 0.49 of Org::Element::Setting (from Perl distribution Org-Parser), released on 2016-07-14.
 
 =head1 DESCRIPTION
 
